#
# spec file for package sisu
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global reltype milestones
Name:           sisu
Version:        0.9.0.M3
Release:        2.0.2.1.sr20240605
Summary:        Eclipse dependency injection framework
License:        BSD-3-Clause AND EPL-1.0 AND EPL-2.0
Group:          Development/Libraries/Java
URL:            https://www.eclipse.org/sisu/
Source0:        https://github.com/eclipse-sisu/sisu-project/archive/refs/tags/%{reltype}/%{version}.tar.gz#/sisu-project-%{version}.tar.gz
Source1:        %{name}-build.tar.xz
Patch1:         sisu-no-dependency-on-glassfish-servlet-api.patch
Patch3:         sisu-osgi-api.patch
Patch4:         sisu-reproducible-index.patch
BuildRequires:  ant
BuildRequires:  atinject
BuildRequires:  cdi-api
BuildRequires:  fdupes
BuildRequires:  glassfish-annotation-api
BuildRequires:  google-guice
BuildRequires:  guice-servlet
BuildRequires:  jakarta-inject
BuildRequires:  javapackages-local >= 6
BuildRequires:  junit
BuildRequires:  junit5-minimal
BuildRequires:  osgi-core
BuildRequires:  plexus-classworlds
BuildRequires:  plexus-containers-component-annotations
BuildRequires:  plexus-utils
BuildRequires:  plexus-xml
BuildRequires:  slf4j
BuildRequires:  testng
BuildRequires:  unzip
BuildRequires:  xz
Provides:       bundled(objectweb-asm)
BuildArch:      noarch

%description
Java dependency injection framework with backward support for plexus and bean
style dependency injection.

%package        inject
Summary:        Sisu inject
Group:          Development/Libraries/Java

%description    inject
This package contains %{summary}.

%package        plexus
Summary:        Sisu Plexus
Group:          Development/Libraries/Java
Requires:       %{name}-inject = %{version}
Obsoletes:      plexus-containers-container-default < 2.2.0
Provides:       plexus-containers-container-default = 2.2.0

%description    plexus
This package contains %{summary}.

%package        javadoc
Summary:        API documentation for Sisu
Group:          Documentation/HTML

%description    javadoc
This package contains %{summary}.

%prep
%setup -q -n sisu-project-%{reltype}-%{version} -a1

%patch -P 1 -p1
%patch -P 3 -p1
%patch -P 4 -p2

%build
mkdir -p lib
build-jar-repository -s lib \
  atinject \
  cdi-api \
  glassfish-annotation-api \
  google-guice-no_aop \
  jakarta-inject \
  junit \
  junit5 \
  osgi-core/osgi.core \
  plexus/utils \
  plexus/xml \
  plexus/classworlds \
  plexus-containers/plexus-component-annotations \
  slf4j/api \
  testng
%{ant} package javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 org.eclipse.sisu.inject/target/org.eclipse.sisu.inject-%{version}.jar \
    %{buildroot}%{_javadir}/org.eclipse.sisu.inject.jar
install -pm 0644 org.eclipse.sisu.plexus/target/org.eclipse.sisu.plexus-%{version}.jar \
    %{buildroot}%{_javadir}/org.eclipse.sisu.plexus.jar
# Compatibility symlink
install -dm 0755 %{buildroot}%{_javadir}/plexus-containers
ln -sf %{_javadir}/org.eclipse.sisu.plexus.jar %{buildroot}%{_javadir}/plexus-containers/plexus-container-default.jar

# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}
%{mvn_install_pom} org.eclipse.sisu.inject/pom.xml %{buildroot}%{_mavenpomdir}/org.eclipse.sisu.inject.pom
%add_maven_depmap org.eclipse.sisu.inject.pom org.eclipse.sisu.inject.jar -f inject
%{mvn_install_pom} org.eclipse.sisu.plexus/pom.xml %{buildroot}%{_mavenpomdir}/org.eclipse.sisu.plexus.pom
%add_maven_depmap org.eclipse.sisu.plexus.pom org.eclipse.sisu.plexus.jar -f plexus -a org.sonatype.sisu:sisu-inject-plexus,org.codehaus.plexus:plexus-container-default

# javadoc
for i in inject plexus; do
  install -dm 0755 %{buildroot}%{_javadocdir}/%{name}/%{name}-${i}
  cp -pr org.eclipse.sisu.${i}/target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/%{name}-${i}/
done
%fdupes -s %{buildroot}%{_javadocdir}

%files inject -f .mfiles-inject
%license LICENSE.txt

%files plexus -f .mfiles-plexus
%{_javadir}/plexus-containers

%files javadoc
%license LICENSE.txt
%{_javadocdir}/%{name}

%changelog
* Mon Jun 10 2024 Fridrich Strba <fstrba@suse.com>
- Add dependency on jakarta-inject, needed by google-guice 6.0.0
* Wed Jun  5 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream milestone 0.9.0.M3
  * Changes
    + Annotate new method
    + Update workflow to run on Java 21
    + Build with final Java 21 on GitHub
    + Switch to JUnit5
    + Disable annotation processor by default
    + Do not silently fail in case of class scanning exceptions
    + Formatting issues
    + Update to ASM 9.7
    + Update CONTRIBUTING.md
    + Align Plexus ASM version
    + Rename release profile
    + Fix Jacoco coverage repots in Sonar
    + Add a method to allow LifecycleManager to free keys
    + Licence change: From EPL1 to EPL2
    + update documentation for exposed core extensions, fix anchors
    + Trigger Sonarcloud analysis from GHA
- Build sisu-mojos as a second spec within sisu package, since the
  sources of sisu-mojos, sisu-inject and sisu-plexus were joined in
  the same upstream project
* Thu May 16 2024 Fridrich Strba <fstrba@suse.com>
- Provide plexus-containers-container-default for easier update
* Sun Apr 14 2024 Fridrich Strba <fstrba@suse.com>
- Update to upstream milestone 0.9.0.M2
  * Changes of sisu.inject 0.9.0.M2
    + Fix SpaceScanner to use latest ASM API version
    + 3.7 is not an officially supported version therefore specify
    3.8 instead
    + Provide script to help upgrade embedded copy of ASM
    + ASM_9_4
    + Require Java 8
    + Sisu specific PreConstruct/PreDestroy annotations
    + Update build plugins
    + ASM 9.5
    + Align to latest Maven plugins
    + Move release elements from oss-parent to local project
    + Create a 'no_asm' jar at release time which doesn't embed ASM
  * Changes of sisu.inject 9.0.M1
    + Fix CDI related issues
    + Build with Eclipse/Tycho 2.5.0 and Java 11
    + Raise problem reporting logs to DEBUG, fixes #36
    + Upgrade internal copy of ASM to 9.2
    + Implement PathTypeConverter
    + Add JUnit 5 annotations to InjectedTest setUp/tearDown
    + Fix static parameters binding lookup
    + Run injection tests against multiple versions of Guice
    + Support using @priority on Providers
    + Use read lock when subscribing to publishers…
    + Cache binding lookups for single bean providers
    + Use AtomicReferenceFieldUpdater as it works better for large
    numbers of instances
    + Enable Java CI workflow
    + Enable CodeQL analysis
    + Replace potentially-expensive regex with simple tokenizer
    + Allow Main to boot with extra bindings
    + Re-enable various resource-related unit tests
    + Rework globber pattern strategy to avoid use of regex
    + Use GlobberStrategy.PATTERN instead of regex for
    ServiceBindings filtering
  * Changes of sisu.plexus 0.9.0.M2
    + Make build work with Java17
    + Align to latest Maven plugins
    + Move release elements from oss-parent to local project
  * Changes of sisu.plexus 0.9.0.M1
    + Align logback with sisu.inject
    + Build with Eclipse/Tycho 2.5.0 and Java 11
    + Support configuration of collections with complex generic
    types
    + Enable Java CI workflow
    + Enable CodeQL analysis
- Removed patches:
  * sisu-OSGi-import-guava.patch
  * sisu-ignored-tests.patch
    + not needed with this version any more
- Modified patches:
  * sisu-no-dependency-on-glassfish-servlet-api.patch
  * sisu-osgi-api.patch
  * sisu-reproducible-index.patch
    + rediff to changed context
* Tue Apr  2 2024 Fridrich Strba <fstrba@suse.com>
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Sep  5 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * sisu-reproducible-index.patch
    + Sort the classes by name in META-INF/sisu/javax.inject.Named
    to make the output reproducible
* Wed Apr 27 2022 Fridrich Strba <fstrba@suse.com>
- Change to generate maven meta-data using the %%%%add_maven_depmap
  * so that it can be built before the xmvn-tools
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Tue Jan 18 2022 Fridrich Strba <fstrba@suse.com>
- Update to upstream version 0.3.5
- Changes of 0.3.5
  * beo#539791 - Update cdi-api dependency to 1.2
  * beo#575952 - Support turning off URLConnection caching for
    container related resources
- Changes of 0.3.4
  * beo#552642 - Support reproducible builds by sorting generated
    javax.inject.Named index
  * beo#546874 - Relax bytecode check in scanner so it can scan up
    to and including Java14
- Added patch:
  * sisu-no-dependency-on-glassfish-servlet-api.patch
    + remove dependency on glassfish-servlet-api
* Mon Apr  1 2019 Jan Engelhardt <jengelh@inai.de>
- Use modern tar options.
* Tue Mar 19 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of sisu-inject and sisu-plexus 0.3.3
- Generate and customize ant build files
